@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::EOLTests;
 # ABSTRACT: (DEPRECATED) Release tests making sure correct line endings are used
-$Dist::Zilla::Plugin::EOLTests::VERSION = '0.16';
+$Dist::Zilla::Plugin::EOLTests::VERSION = '0.17';
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::EOL';
 use namespace::autoclean;
@@ -32,7 +32,7 @@ Dist::Zilla::Plugin::EOLTests - (DEPRECATED) Release tests making sure correct l
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -52,28 +52,6 @@ later time (but not before April 2015).
 In the meantime, it will continue working -- although with a warning.
 Refer to the replacement for the full documentation.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-EO
-L or by email to bug-Dist-Zilla-Plugin-Test-EOL@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<Dist::Zilla::Plugin::Test::EOL|Dist::Zilla::Plugin::Test::EOL>
-
-=back
-
 =head1 AUTHORS
 
 =over 4
